==> serenity-reports-2.0.10-sources.jar: net/thucydides/core/reports/html/EvidenceData.java <==
package net.thucydides.core.reports.html;

import net.thucydides.core.model.ReportData;
import net.thucydides.core.model.ReportNamer;
import net.thucydides.core.model.ReportType;
import net.thucydides.core.model.TestOutcome;
import net.thucydides.core.reports.TestOutcomes;

import java.util.ArrayList;
import java.util.List;

public class EvidenceData {

    private final String scenario;
    private final String title;
    private final String detailsLink;

    public EvidenceData(String scenario, String title, String detailsLink) {
        this.scenario = scenario;
        this.title = title;
        this.detailsLink = detailsLink;
    }


    public String getScenario() {
        return scenario;
    }

    public String getTitle() {
        return title;
    }

    public String getDetailsLink() {
        return detailsLink;
    }

    public static List<EvidenceData> from(TestOutcomes testOutcomes) {

        List<EvidenceData> evidence = new ArrayList<>();


        for(TestOutcome testOutcome : testOutcomes.getOutcomes()) {
            for(ReportData reportData : testOutcome.getEvidence()) {
                evidence.add(new EvidenceData(testOutcome.getName(),
                                              reportData.getTitle(),
                                              detailsLinkFor(testOutcome, reportData)));
            }
        }
        return evidence;
    }

    private static String detailsLinkFor(TestOutcome testOutcome, ReportData reportData) {
        if (reportData.getPath() != null) {
            return "<a role='button' target='_blank' class='btn btn-success btn-sm' href='"
                    + reportData.getPath()
                    + "'><i class='fas fa-download'></i>&nbsp;Download Evidence</a>";
        } else {
            String report = ReportNamer.forReportType(ReportType.HTML).getNormalizedTestNameFor(testOutcome);
            return "<a role='button' class='btn btn-success btn-sm' href='"
                    + report + "#" + reportData.getId()
                    + "'><i class=\"fas fa-external-link-alt\"></i>&nbsp;Details</a>";
        }
    }


}

==> serenity-reports-2.0.32-sources.jar: net/thucydides/core/reports/html/EvidenceData.java <==
package net.thucydides.core.reports.html;

import net.thucydides.core.model.ReportData;
import net.thucydides.core.model.ReportNamer;
import net.thucydides.core.model.ReportType;
import net.thucydides.core.model.TestOutcome;
import net.thucydides.core.reports.TestOutcomes;

import java.util.ArrayList;
import java.util.List;

public class EvidenceData {

    private final String scenario;
    private final String title;
    private final String detailsLink;

    public EvidenceData(String scenario, String title, String detailsLink) {
        this.scenario = scenario;
        this.title = title;
        this.detailsLink = detailsLink;
    }


    public String getScenario() {
        return scenario;
    }

    public String getTitle() {
        return title;
    }

    public String getDetailsLink() {
        return detailsLink;
    }

    public static List<EvidenceData> from(TestOutcomes testOutcomes) {

        List<EvidenceData> evidence = new ArrayList<>();


        for(TestOutcome testOutcome : testOutcomes.getOutcomes()) {
            for(ReportData reportData : testOutcome.getEvidence()) {
                evidence.add(new EvidenceData(testOutcome.getQualified().withContext().getTitle(),
                                              reportData.getTitle(),
                                              detailsLinkFor(testOutcome, reportData)));
            }
        }
        return evidence;
    }

    private static String detailsLinkFor(TestOutcome testOutcome, ReportData reportData) {
        if (reportData.getPath() != null) {
            return "<a role='button' target='_blank' class='btn btn-success btn-sm' href='"
                    + reportData.getPath()
                    + "'><i class='fas fa-download'></i>&nbsp;Download Evidence</a>";
        } else {
            String report = ReportNamer.forReportType(ReportType.HTML).getNormalizedTestNameFor(testOutcome);
            return "<a role='button' class='btn btn-success btn-sm' href='"
                    + report + "#" + reportData.getId()
                    + "'><i class=\"fas fa-external-link-alt\"></i>&nbsp;Details</a>";
        }
    }


}
